NBLocation class

Constructors

NBLocation({required num latitude, required num longitude, required num accuracy, required num altitude, required num speed, required num speedAccuracy, required num heading, required String provider, required num timestamp})
NBLocation.fromJson(String? jsonString)
factory

Properties

accuracy num
final
altitude num
final
hashCode int
The hash code for this object.
no setterinherited
heading num
final
latitude num
final
longitude num
final
provider String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
speed num
final
speedAccuracy num
final
timestamp num
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited