IOSNotificationConfig class
Constructors
- IOSNotificationConfig()
- IOSNotificationConfig.fromJson(String jsonString)
-
factory
Properties
- assetDisableNotificationConfig ↔ AssetDisableNotificationConfig
-
getter/setter pair
- assetEnableNotificationConfig ↔ AssetEnableNotificationConfig
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- lowBatteryNotificationConfig ↔ LowBatteryStatusNotificationConfig
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showAssetDisableNotification ↔ bool
-
getter/setter pair
- showAssetEnableNotification ↔ bool
-
getter/setter pair
- showLowBatteryNotification ↔ bool
-
getter/setter pair
Methods
-
encode(
) → String -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited